%global systemd_units tracker-xdg-portal-3

Summary:        Desktop-neutral metadata database and search tool
Name:           tracker
Version:        3.5.3
Release:        6%{?dist}
License:        GPLv2+
URL:            https://gnome.pages.gitlab.gnome.org/tracker/
Source0:        https://download.gnome.org/sources/tracker/3.4/tracker-%{version}.tar.xz

BuildRequires:  asciidoc, gettext, libstemmer-devel, meson, python3-gobject, systemd-rpm-macros, vala
BuildRequires:  pkgconfig(dbus-1), pkgconfig(gobject-introspection-1.0), pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc), pkgconfig(json-glib-1.0), pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0), pkgconfig(sqlite3)
BuildRequires:  /usr/bin/dbus-run-session
Requires:       libtracker-sparql = %{version}-%{release}
Recommends:     tracker-miners
Provides:       tracker3 = %{version}-%{release}

%description
Tracker is an efficient search engine and distributed database for desktop, 
embedded and mobile.

It is a middleware component aimed at desktop application developers who 
want their apps to browse and search user content. It’s not designed to 
be used directly by desktop users, but it provides a commandline tool 
named tracker3 for the adventurous.

Tracker allows your application to instantly perform full-text searches 
across all documents. This feature is used by the 'search' bar in GNOME Files, for example.

Tracker also allows your application to query and list content that the user has stored. 
For example, GNOME Music displays all the music files that are found by Tracker. 
This means that GNOME Music doesn't need to maintain a database of its own.

%package -n     libtracker-sparql
Summary:        Tracker SPARQL library
License:        LGPLv2+
Recommends:     tracker = %{version}-%{release}
Provides:       libtracker-sparql3 = %{version}-%{release}

%description -n libtracker-sparql
This package contains the libtracker-sparql library.


%package        devel
Summary:        Development files for tracker 
Requires:       libtracker-sparql = %{version}-%{release}
Provides:       tracker3-devel = %{version}-%{release}

%description devel
The tracker-devel package contains libraries and header files for
developing applications that use tracker.


%package        doc
Summary:        Documentation for tracker 
Provides:       tracker3-doc = %{version}-%{release}
BuildArch:      noarch

%description doc
The tracker-devel package contains the documentation for tracker.


%prep
%autosetup -n tracker-%{version}


%build
%meson \
  -Dunicode_support=icu \
  -Dsystemd_user_services_dir=%{_userunitdir} \
  %{nil}

%meson_build


%install
%meson_install

%find_lang tracker3


%post
%systemd_user_post %{systemd_units}

%preun
%systemd_user_preun %{systemd_units}

%postun
%systemd_user_postun_with_restart %{systemd_units}


%files -f tracker3.lang
%license COPYING COPYING.GPL
%doc AUTHORS NEWS README.md
%{_bindir}/tracker3
%{_libexecdir}/tracker3/
%{_libexecdir}/tracker-xdg-portal-3
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/tracker3
%{_datadir}/dbus-1/services/org.freedesktop.portal.Tracker.service
%{_mandir}/man1/tracker*.1*
%{_userunitdir}/tracker-xdg-portal-3.service

%files -n libtracker-sparql
%license COPYING COPYING.LGPL
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Tracker-3.0.typelib
%{_libdir}/libtracker-sparql-3.0.so.0*
%{_libdir}/tracker-3.0/
%{_datadir}/tracker3/

%files devel
%{_includedir}/tracker-3.0/
%{_libdir}/libtracker-sparql-3.0.so
%{_libdir}/pkgconfig/*.pc
%dir %{_libdir}/tracker-3.0
%{_libdir}/tracker-3.0/trackertestutils/
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/tracker-sparql-3.0.*
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Tracker-3.0.gir

%files doc
%license docs/reference/COPYING
%{_docdir}/Tracker-3.0/


%changelog
* Thu Dec 19 2024 Miaojun Dong <zoedong@tencent.com> - 3.5.3-6
- Rebuilt for icu 74.2

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.5.3-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.5.3-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.5.3-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 3.5.3-2
- Rebuilt for icu 73.2

* Thu Aug 17 2023 Shuo Wang <abushwang@tencent.com> - 3.5.3-1
- update to 3.5.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.4.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.4.1-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 12 2022 Wang Guodong <gordonwwang@tencent.com> - 3.4.1-2
- Provides libtracker-sparql3, tracker3-devel, tracker3-doc.

* Mon Aug 29 2022 frankjlli <frankjlli@tencent.com> - 3.4.1-1
- Initial build
